@@ -1,47 +1,12 @@
 package Games::ABC_Path::MicrosoftRand;
-$Games::ABC_Path::MicrosoftRand::VERSION = '0.4.3';
+$Games::ABC_Path::MicrosoftRand::VERSION = '0.6.0';
 use 5.006;
 use strict;
 use warnings;
 
 
 use integer;
-
-use Class::XSAccessor {
-    constructor => 'new',
-    accessors   => [qw(seed)],
-};
-
-sub rand
-{
-    my $self = shift;
-    $self->seed( ( $self->seed() * 214013 + 2531011 ) & (0x7FFF_FFFF) );
-    return ( ( $self->seed >> 16 ) & 0x7fff );
-}
-
-sub max_rand
-{
-    my ( $self, $max ) = @_;
-
-    return ( $self->rand() % $max );
-}
-
-sub shuffle
-{
-    my ( $self, $deck ) = @_;
-
-    if (@$deck)
-    {
-        my $i = @$deck;
-        while ( --$i )
-        {
-            my $j = $self->max_rand( $i + 1 );
-            @$deck[ $i, $j ] = @$deck[ $j, $i ];
-        }
-    }
-
-    return $deck;
-}
+use parent 'Math::RNG::Microsoft';
 
 
 
@@ -60,7 +25,7 @@ with Visual C.
 
 =head1 VERSION
 
-version 0.4.3
+version 0.6.0
 
 =head1 SYNOPSIS
 
@@ -110,7 +75,7 @@ it. This is using the fisher-yates shuffle.
 
 =head1 AUTHOR
 
-Shlomi Fish, L<http://www.shlomifish.org/> .
+Shlomi Fish, L<https://www.shlomifish.org/> .
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
@@ -204,7 +169,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Shlomi Fish.
+This software is Copyright (c) 2021 by Shlomi Fish.
 
 This is free software, licensed under:
 
